@@ -1,3 +1,3 @@
 from .smolagents import SmolAgentsAdapter
 from .llamaindex import LlamaIndexAdapter
-from .chainlit import ChainlitAdapter
\ No newline at end of file
+from .chainlit import ChainlitAdapter, ChainlitXpanderDataLayer
\ No newline at end of file
