@@ -9,6 +9,7 @@ from xpander_sdk import (
     ToolCallType,
     ToolCallResult,
     LLMProvider,
+    SourceNodeType
 )
 from ...generic import get_sub_agent_id_from_oas_by_name
 from .base import SDKAdapter
@@ -537,6 +538,7 @@ class ChainlitAdapter(SDKAdapter):
             is_agent_end_tool = True if tool_call.name == AGENT_END_TOOL else False
             
             current_step = cl.context.current_step
+            
             tool_name = tool_call.name
             
             tool_agent_id = get_sub_agent_id_from_oas_by_name(agent_name=tool_call.name,oas=self.agent.oas)
@@ -547,9 +549,10 @@ class ChainlitAdapter(SDKAdapter):
                     
             if is_sub_agent:
                 if is_agent_end_tool:
-                    tool_name = f"-> {self.agent.name} (Sub agent) -> Thought & Finish"
+                    tool_name = f"{self.agent.name} - Final Thought"
                 else:
-                    tool_name = f"-> {self.agent.name} (Sub agent) -> {tool_call.name}"
+                    tool_name = f"{self.agent.name} - {tool_call.name}"
+                    
             elif is_agent_end_tool:
                 tool_name = f"Crafting final answer"
             
@@ -576,11 +579,12 @@ class ChainlitAdapter(SDKAdapter):
                 except Exception as e:
                     tool_call_result.result = str(e)
                     tool_call_result.is_error = True
+                    current_step.is_error = True
                 
                 # report result to the memory
                 self.agent.add_tool_call_results(tool_call_results=[tool_call_result])
             else:
-                tool_call_result = self.agent.run_tool(tool=tool_call)
+                tool_call_result = self.agent.run_tool(tool=tool_call,payload_extension={"headers":{"x-xpander-source-node-type": SourceNodeType.ASSISTANT.value.lower()}})
             
             if is_agent_end_tool:
                 current_step.output = tool_call_result.payload['bodyParams']['result']
